member

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Member

type Member struct {
	// contains filtered or unexported fields
}

Member struct Member is for specify if a user is member this does authority control

func New

func New(github *github.Client, member config.Member) *Member

New create member

func (*Member) IfMember

func (m *Member) IfMember(login string) bool

IfMember make cache and check if a user is member

Jump to